<?php

namespace Litecms\Property\Policies;

use Litecms\Property\Models\Property;
use Illuminate\Foundation\Auth\User as Authenticatable;

trait PropertyWorkflow
{

    /**
     * Determine if the given user can approve the given property.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function approve(Authenticatable $user, Property $property)
    {
        if ($user->canDo('property.property.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given property.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function submit(Authenticatable $user, Property $property)
    {
        if ($user->canDo('property.property.submit')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given property.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function publish(Authenticatable $user, Property $property)
    {
        if ($user->canDo('property.property.publish')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given property.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function unpublish(Authenticatable $user, Property $property)
    {
        if ($user->canDo('property.property.unpublish')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given property.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function archive(Authenticatable $user, Property $property)
    {
        if ($user->canDo('property.property.archive')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given property.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function unarchive(Authenticatable $user, Property $property)
    {
        if ($user->canDo('property.property.unarchive')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given property.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function reject(Authenticatable $user, Property $property)
    {
        if ($user->canDo('property.property.reject')) {
            return true;
        }

        return false;
    }

}
